@@ -500,6 +500,24 @@ class MessageProcessor:
             or tracker.latest_message.intent.get("name") == USER_INTENT_RESTART
         )
 
+    def is_action_limit_reached(
+        self, num_predicted_actions: int, should_predict_another_action: bool
+    ) -> bool:
+        """Check whether the maximum number of predictions has been met.
+
+        Args:
+            num_predictes_actions: Number of predicted actions.
+            should_predict_another_action: Whether the last executed action allows
+            for more actions to be predicted or not.
+
+        Returns:
+            `True` if the limit of actions to predict has been reached.
+        """
+        return (
+            num_predicted_actions >= self.max_number_of_predictions
+            and should_predict_another_action
+        )
+
     async def _predict_and_execute_next_action(
         self, output_channel: OutputChannel, tracker: DialogueStateTracker
     ):
@@ -507,12 +525,6 @@ class MessageProcessor:
         should_predict_another_action = True
         num_predicted_actions = 0
 
-        def is_action_limit_reached():
-            return (
-                num_predicted_actions == self.max_number_of_predictions
-                and should_predict_another_action
-            )
-
         # action loop. predicts actions until we hit action listen
         while (
             should_predict_another_action
@@ -527,7 +539,9 @@ class MessageProcessor:
             )
             num_predicted_actions += 1
 
-        if is_action_limit_reached():
+        if self.is_action_limit_reached(
+            num_predicted_actions, should_predict_another_action
+        ):
             # circuit breaker was tripped
             logger.warning(
                 "Circuit breaker tripped. Stopped predicting "
