@@ -288,7 +288,11 @@ def _emulate_form_rejection(processor, partial_tracker):
 
 
 def _collect_action_executed_predictions(
-    processor, partial_tracker, event, fail_on_prediction_errors
+    processor,
+    partial_tracker,
+    event,
+    fail_on_prediction_errors,
+    circuit_breaker_tripped,
 ):
     from rasa.core.policies.form_policy import FormPolicy
 
@@ -296,17 +300,22 @@ def _collect_action_executed_predictions(
 
     gold = event.action_name
 
-    action, policy, confidence = processor.predict_next_action(partial_tracker)
-    predicted = action.name()
-
-    if policy and predicted != gold and FormPolicy.__name__ in policy:
-        # FormPolicy predicted wrong action
-        # but it might be Ok if form action is rejected
-        _emulate_form_rejection(processor, partial_tracker)
-        # try again
+    if circuit_breaker_tripped:
+        predicted = "circuit breaker tripped"
+        policy = None
+        confidence = None
+    else:
         action, policy, confidence = processor.predict_next_action(partial_tracker)
         predicted = action.name()
 
+        if policy and predicted != gold and FormPolicy.__name__ in policy:
+            # FormPolicy predicted wrong action
+            # but it might be Ok if form action is rejected
+            _emulate_form_rejection(processor, partial_tracker)
+            # try again
+            action, policy, confidence = processor.predict_next_action(partial_tracker)
+            predicted = action.name()
+
     action_executed_eval_store.add_to_store(
         action_predictions=predicted, action_targets=gold
     )
@@ -352,15 +361,24 @@ def _predict_tracker_actions(
     )
 
     tracker_actions = []
+    should_predict_another_action = True
+    num_predicted_actions = 0
 
     for event in events[1:]:
         if isinstance(event, ActionExecuted):
+            circuit_breaker_tripped = processor.is_action_limit_reached(
+                num_predicted_actions, should_predict_another_action
+            )
             (
                 action_executed_result,
                 policy,
                 confidence,
             ) = _collect_action_executed_predictions(
-                processor, partial_tracker, event, fail_on_prediction_errors
+                processor,
+                partial_tracker,
+                event,
+                fail_on_prediction_errors,
+                circuit_breaker_tripped,
             )
             tracker_eval_store.merge_store(action_executed_result)
             tracker_actions.append(
@@ -371,6 +389,11 @@ def _predict_tracker_actions(
                     "confidence": confidence,
                 }
             )
+            should_predict_another_action = processor.should_predict_another_action(
+                action_executed_result.action_predictions[0]
+            )
+            num_predicted_actions += 1
+
         elif use_e2e and isinstance(event, UserUttered):
             user_uttered_result = _collect_user_uttered_predictions(
                 event, partial_tracker, fail_on_prediction_errors
@@ -379,6 +402,8 @@ def _predict_tracker_actions(
             tracker_eval_store.merge_store(user_uttered_result)
         else:
             partial_tracker.update(event)
+        if isinstance(event, UserUttered):
+            num_predicted_actions = 0
 
     return tracker_eval_store, partial_tracker, tracker_actions
 
@@ -661,7 +686,7 @@ async def _evaluate_core_model(model: Text, stories_file: Text) -> int:
 
 
 def plot_nlu_results(output: Text, number_of_examples: List[int]) -> None:
-
+    """Plot NLU model comparison graph"""
     graph_path = os.path.join(output, "nlu_model_comparison_graph.pdf")
 
     _plot_curve(
@@ -674,7 +699,7 @@ def plot_nlu_results(output: Text, number_of_examples: List[int]) -> None:
 
 
 def plot_core_results(output: Text, number_of_examples: List[int]) -> None:
-
+    """Plot core model comparison graph"""
     graph_path = os.path.join(output, "core_model_comparison_graph.pdf")
 
     _plot_curve(
